==> v0.4.0.tar.gz: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/index/query/json/PrefixJsonQueryBuilder.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.query.json;

import org.elasticsearch.util.json.JsonBuilder;

import java.io.IOException;

/**
 * @author kimchy (Shay Banon)
 */
public class PrefixJsonQueryBuilder extends BaseJsonQueryBuilder {

    private final String name;

    private final String value;

    private float boost = -1;

    public PrefixJsonQueryBuilder(String name, String value) {
        this.name = name;
        this.value = value;
    }

    public PrefixJsonQueryBuilder boost(float boost) {
        this.boost = boost;
        return this;
    }

    @Override public void doJson(JsonBuilder builder) throws IOException {
        builder.startObject(PrefixJsonQueryParser.NAME);
        if (boost == -1) {
            builder.field(name, value);
        } else {
            builder.startObject(name);
            builder.field("prefix", value);
            builder.field("boost", boost);
            builder.endObject();
        }
        builder.endObject();
    }
}

==> v0.5.1.tar.gz: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/index/query/json/PrefixJsonQueryBuilder.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.query.json;

import org.elasticsearch.util.json.JsonBuilder;

import java.io.IOException;

/**
 * A Query that matches documents containing terms with a specified prefix.
 *
 * @author kimchy (shay.banon)
 */
public class PrefixJsonQueryBuilder extends BaseJsonQueryBuilder {

    private final String name;

    private final String prefix;

    private float boost = -1;

    /**
     * A Query that matches documents containing terms with a specified prefix.
     *
     * @param name   The name of the field
     * @param prefix The prefix query
     */
    public PrefixJsonQueryBuilder(String name, String prefix) {
        this.name = name;
        this.prefix = prefix;
    }

    /**
     * Sets the boost for this query.  Documents matching this query will (in addition to the normal
     * weightings) have their score multiplied by the boost provided.
     */
    public PrefixJsonQueryBuilder boost(float boost) {
        this.boost = boost;
        return this;
    }

    @Override public void doJson(JsonBuilder builder, Params params) throws IOException {
        builder.startObject(PrefixJsonQueryParser.NAME);
        if (boost == -1) {
            builder.field(name, prefix);
        } else {
            builder.startObject(name);
            builder.field("prefix", prefix);
            builder.field("boost", boost);
            builder.endObject();
        }
        builder.endObject();
    }
}
